`klimalogger <https://github.com/wuan/klimalogger>`_
============================================

.. image:: https://badge.fury.io/gh/wuan%2Fklimalogger.svg
    :alt: project on GitHub
    :target: http://badge.fury.io/gh/wuan%2Fklimalogger
.. image:: https://badge.fury.io/py/klimalogger.svg
    :alt: PyPi-Package
    :target: https://badge.fury.io/py/klimalogger
.. image:: https://travis-ci.org/wuan/klimalogger.svg?branch=master
    :alt: Build Status
    :target: https://travis-ci.org/wuan/klimalogger
.. image:: https://coveralls.io/repos/wuan/klimalogger/badge.svg?branch=master&service=github
    :target: https://coveralls.io/github/wuan/klimalogger?branch=master

Simple python client for logging measured climate data to InfluxDb.
